@@ -1,3 +1,6 @@
+#!/bin/sh
+exec guile -s "$0"
+!#
 
 (use-modules (test gw-test-child))
 (use-modules (test gw-test-parent))
@@ -23,6 +26,13 @@
     (if (equal? obj-1 coerced-obj)
         (display "yes\n")
         (error "no")))
+
+  (display "checking that one module can use another module's types...")
+  (let* ((obj-1 (gw-test-parent-make-obj "object 1"))
+         (passed-obj (gw-test-child-pass-back-parent-obj obj-1)))
+    (if (equal? obj-1 passed-obj)
+        (display "yes\n")
+        (error "no")))
   )
 
 (define (run-test . args)
@@ -30,4 +40,6 @@
 
 (define (run-test-and-quit . args)
   (run-test)
-  (exit 0))
\ No newline at end of file
+  (exit 0))
+
+(run-test-and-quit)
